import re
from datetime import datetime

def generate_report_summary(file_path):
    """
    Generuje podsumowanie raportu finansowego
    """
    try:
        with open(file_path, 'r', encoding='utf-8') as f:
            content = f.read()
            
        summary = {
            "data_raportu": None,
            "kluczowe_wskazniki": {
                "przychody": None,
                "zysk_netto": None,
                "aktywa_razem": None,
                "zobowiazania": None
            },
            "najwazniejsze_zmiany": [],
            "ryzyka": [],
            "perspektywy": []
        }
        
        # Wyciągnij datę raportu
        date_match = re.search(r'(\d{4}-\d{2}-\d{2})', file_path)
        if date_match:
            summary["data_raportu"] = date_match.group(1)
            
        # Znajdź kluczowe wskaźniki finansowe
        revenue_match = re.search(r'Revenue[:\s]+\$([\d,\.]+)', content)
        if revenue_match:
            summary["kluczowe_wskazniki"]["przychody"] = revenue_match.group(1)
            
        # Znajdź najważniejsze zmiany
        changes_section = re.search(r'Changes in.+?(?=\n\n)', content, re.DOTALL)
        if changes_section:
            changes = changes_section.group(0).split('\n')
            summary["najwazniejsze_zmiany"] = [c.strip() for c in changes if c.strip()]
            
        # Znajdź ryzyka
        risks_section = re.search(r'Risk Factors.+?(?=\n\n)', content, re.DOTALL)
        if risks_section:
            risks = risks_section.group(0).split('\n')
            summary["ryzyka"] = [r.strip() for r in risks if r.strip()]
            
        return format_summary(summary)
        
    except Exception as e:
        return f"Błąd podczas generowania podsumowania: {str(e)}"

def format_summary(summary):
    """
    Formatuje podsumowanie do czytelnej postaci
    """
    output = []
    output.append("=== PODSUMOWANIE RAPORTU FINANSOWEGO ===\n")
    
    if summary["data_raportu"]:
        output.append(f"Data raportu: {summary['data_raportu']}\n")
        
    output.append("\nKLUCZOWE WSKAŹNIKI FINANSOWE:")
    for key, value in summary["kluczowe_wskazniki"].items():
        if value:
            output.append(f"- {key.replace('_', ' ').title()}: ${value}")
            
    if summary["najwazniejsze_zmiany"]:
        output.append("\nNAJWAŻNIEJSZE ZMIANY:")
        for change in summary["najwazniejsze_zmiany"][:5]:  # Top 5 zmian
            output.append(f"- {change}")
            
    if summary["ryzyka"]:
        output.append("\nKLUCZOWE RYZYKA:")
        for risk in summary["ryzyka"][:5]:  # Top 5 ryzyk
            output.append(f"- {risk}")
            
    return "\n".join(output)

# Użycie:
if __name__ == "__main__":
    file_path = "reports/0001385849/2023-08-04_10-Q.txt"
    summary = generate_report_summary(file_path)
    print(summary) 